argon2pure Changelog
====================

1.1.1 (2016-06-17)
------------------

- Fix setup.py typo.  (Fixes #1)

Thanks to: Eli Collins


1.1 (2016-02-06)
----------------

Performance improvements.

- Faster XORing of blocks.
- Use multiple threads if possible.


1 (2016-01-21)
--------------

- Initial release.
